@@ -72,6 +72,9 @@ class PbsManager(HpcManagerInterface):
     def get_current_job_id(self):
         assert False
 
+    def get_job_stats(self, job_id):
+        return None
+
     def get_local_scratch(self):
         return "."
 
